<?php
/**
 * @file
 * Drush command to get latest schema version for a module.
 */

/**
 * Implements hook_drush_command().
 */
function schema_version_drush_command() {
  $items = array();

  $items['schema-version'] = array(
    'description' => 'Show latest schema version.',
    'arguments' => array(
      'module' => 'Module name.',
    ),
    'examples' => array(
      'drush sv views' => 'Show latest schema version of the views module.',
    ),
    'aliases' => array('sv'),
    'bootstrap' => DRUSH_BOOTSTRAP_DRUPAL_DATABASE,
  );

  return $items;
}

/**
 * Implements hook_drush_help().
 */
function schema_version_drush_help($section) {
  switch ($section) {
    case 'drush:schema-version':
      return dt('Show latest schema version.');
  }
}

/**
 * Validate callback.
 */
function drush_schema_version_validate($module = '') {
  if (empty($module)) {
    return drush_set_error('Please enter module name.');
  }
}

/**
 * Command callback.
 */
function drush_schema_version($module = '') {
  drush_print($module);
  $module_object = db_query("SELECT * FROM {system} WHERE name = :name", array(':name' => $module))->fetchObject();
  $items[] = array(
    dt('Name'),
    dt('Version'),
    dt('Status'),
    dt('Weight'),
    dt('Bootstrap'),
  );

  $status = dt('Not installed');
  if ($module_object->status) {
    $status = dt('Enabled');
  }
  elseif (!$module_object->status && $module_object->schema_version > 0) {
    $status = dt('Disabled');
  }

  $items[] = array(
    $module_object->name,
    $module_object->schema_version,
    $status,
    $module_object->weight,
    $module_object->bootstrap,
  );
  drush_print_table($items, TRUE);
}
